@@ -93,10 +93,9 @@ gtfs_transfer_table <- function (gtfs,
         min_transfer_time = ceiling (transfer_times)
     )
 
-    index <- which (!duplicated (transfers [, c (
-        "from_stop_id",
-        "to_stop_id"
-    )]))
+    # See #114: data.table::duplicated currently segfaults (Jan 2024):
+    ft <- data.frame (transfers [, c ("from_stop_id", "to_stop_id")])
+    index <- which (!duplicated (ft))
     transfers <- transfers [index, ]
 
     # Those transfers only include times, but these may then correspond to
@@ -131,9 +130,9 @@ dl_net <- function (gtfs) {
     stops <- gtfs$stops [, c ("stop_lon", "stop_lat")]
     requireNamespace ("digest")
     hash <- digest::digest (stops)
-    net_name <- file.path (tempdir (), paste0 ("net", hash, ".Rds"))
+    net_name <- fs::path (fs::path_temp (), paste0 ("net", hash, ".Rds"))
 
-    if (!file.exists (net_name)) {
+    if (!fs::file_exists (net_name)) {
         requireNamespace ("dodgr")
         net <- dodgr::dodgr_streetnet_sc (pts = stops)
         saveRDS (net, file = net_name)
