@@ -6,6 +6,12 @@
 #' @return Path to newly created zip file
 #' @family extract
 #' @export
+#'
+#' @examples
+#' path <- berlin_gtfs_to_zip ()
+#' gtfs <- extract_gtfs (path)
+#' gtfs <- gtfs_timetable (gtfs, day = "Wed") # A pre-processing step to speed up queries
+#' gtfs_route (gtfs, from = "Tegel", to = "Berlin Hauptbahnhof", start_time = 12 * 3600)
 berlin_gtfs_to_zip <- function () {
     flist <- c (
         "calendar.txt",
@@ -21,7 +27,7 @@ berlin_gtfs_to_zip <- function () {
         si <- strsplit (i, ".txt") [[1]]
         res <- tryCatch (
             data.table::fwrite (f [[si]],
-                file.path (tempdir (), i),
+                fs::path (fs::path_temp (), i),
                 quote = TRUE
             ),
             error = function (e) e
@@ -33,10 +39,10 @@ berlin_gtfs_to_zip <- function () {
         stop ("Unable to write files to tempdir()")
     } # nocov
 
-    flist <- file.path (tempdir (), flist)
-    zipname <- file.path (tempdir (), "vbb.zip")
+    flist <- fs::path (fs::path_temp (), flist)
+    zipname <- fs::path (fs::path_temp (), "vbb.zip")
     utils::zip (zipname, files = flist, flags = "-q")
-    chk <- file.remove (flist)
+    chk <- fs::file_delete (flist)
 
     return (zipname)
 }
